@@ -63,10 +63,6 @@ my @constants = qw/
   GEARMAN_COMMAND_WORK_FAIL
   GEARMAN_COMMAND_WORK_STATUS
   GEARMAN_COMMAND_WORK_WARNING
-  GEARMAN_CONF_ALLOCATED
-  GEARMAN_CONF_DISPLAY_WIDTH
-  GEARMAN_CONF_MAX_OPTION_SHORT
-  GEARMAN_CONF_MODULE_ALLOCATED
   GEARMAN_CON_ALLOCATED
   GEARMAN_CON_CLOSE_AFTER_FLUSH
   GEARMAN_CON_EXTERNAL_FD
@@ -87,8 +83,6 @@ my @constants = qw/
   GEARMAN_CON_STATE_CONNECTING
   GEARMAN_COULD_NOT_CONNECT
   GEARMAN_DATA_TOO_LARGE
-  GEARMAN_DEFAULT_BACKLOG
-  GEARMAN_DEFAULT_MAX_QUEUE_SIZE
   GEARMAN_DEFAULT_SOCKET_RECV_SIZE
   GEARMAN_DEFAULT_SOCKET_SEND_SIZE
   GEARMAN_DEFAULT_SOCKET_TIMEOUT
@@ -112,7 +106,6 @@ my @constants = qw/
   GEARMAN_JOB_EXISTS
   GEARMAN_JOB_FINISHED
   GEARMAN_JOB_HANDLE_SIZE
-  GEARMAN_JOB_HASH_SIZE
   GEARMAN_JOB_PRIORITY_HIGH
   GEARMAN_JOB_PRIORITY_LOW
   GEARMAN_JOB_PRIORITY_MAX
@@ -125,11 +118,6 @@ my @constants = qw/
   GEARMAN_MAGIC_TEXT
   GEARMAN_MAX_COMMAND_ARGS
   GEARMAN_MAX_ERROR_SIZE
-  GEARMAN_MAX_FREE_SERVER_CLIENT
-  GEARMAN_MAX_FREE_SERVER_CON
-  GEARMAN_MAX_FREE_SERVER_JOB
-  GEARMAN_MAX_FREE_SERVER_PACKET
-  GEARMAN_MAX_FREE_SERVER_WORKER
   GEARMAN_MAX_RETURN
   GEARMAN_MEMORY_ALLOCATION_FAILURE
   GEARMAN_NEED_WORKLOAD_FN
@@ -146,7 +134,6 @@ my @constants = qw/
   GEARMAN_PACKET_FREE_DATA
   GEARMAN_PACKET_HEADER_SIZE
   GEARMAN_PAUSE
-  GEARMAN_PIPE_BUFFER_SIZE
   GEARMAN_PIPE_EOF
   GEARMAN_PTHREAD
   GEARMAN_QUEUE_ERROR
@@ -155,21 +142,7 @@ my @constants = qw/
   GEARMAN_SEND_BUFFER_SIZE
   GEARMAN_SEND_BUFFER_TOO_SMALL
   GEARMAN_SEND_IN_PROGRESS
-  GEARMAN_SERVER_ALLOCATED
-  GEARMAN_SERVER_CLIENT_ALLOCATED
-  GEARMAN_SERVER_CON_DEAD
-  GEARMAN_SERVER_CON_EXCEPTIONS
-  GEARMAN_SERVER_CON_ID_SIZE
-  GEARMAN_SERVER_CON_SLEEPING
   GEARMAN_SERVER_ERROR
-  GEARMAN_SERVER_FUNCTION_ALLOCATED
-  GEARMAN_SERVER_JOB_ALLOCATED
-  GEARMAN_SERVER_JOB_IGNORE
-  GEARMAN_SERVER_JOB_QUEUED
-  GEARMAN_SERVER_PROC_THREAD
-  GEARMAN_SERVER_QUEUE_REPLAY
-  GEARMAN_SERVER_THREAD_ALLOCATED
-  GEARMAN_SERVER_WORKER_ALLOCATED
   GEARMAN_SHUTDOWN
   GEARMAN_SHUTDOWN_GRACEFUL
   GEARMAN_SUCCESS
@@ -187,7 +160,7 @@ my @constants = qw/
   GEARMAN_TASK_STATE_WARNING
   GEARMAN_TASK_STATE_WORK
   GEARMAN_TASK_STATE_WORKLOAD
-  GEARMAN_TEXT_RESPONSE_SIZE
+  GEARMAN_TIMEOUT
   GEARMAN_TOO_MANY_ARGS
   GEARMAN_UNEXPECTED_PACKET
   GEARMAN_UNIQUE_SIZE
@@ -215,6 +188,7 @@ my @constants = qw/
   GEARMAN_WORKER_STATE_GRAB_JOB_SEND
   GEARMAN_WORKER_STATE_PRE_SLEEP
   GEARMAN_WORKER_STATE_START
+  GEARMAN_WORKER_TIMEOUT_RETURN
   GEARMAN_WORKER_WAIT_TIMEOUT
   GEARMAN_WORKER_WORK_JOB_IN_USE
   GEARMAN_WORKER_WORK_STATE_COMPLETE
@@ -234,7 +208,7 @@ our @EXPORT_OK = @constants;
 
 our @ISA;
 BEGIN {
-  our $VERSION= '0.5';
+  our $VERSION= '0.6';
 
   eval {
     require XSLoader;
@@ -289,4 +263,4 @@ it under the same terms as Perl itself.
 
 Dennis Schoen <dennis@blogma.de>
 
-=cut
\ No newline at end of file
+=cut
